#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = "Vadym Stupakov"
__email__ = "vadim.stupakov@gmail.com"

from .AboutDialog import AboutDialog
from .BatchAddUrls import BatchAddDialogue
from .LicenseDialog import LicenseDialogue
